<!-- ## Rule LGEDV_CRCL_0003:
Definition: Allows up to 1 return point in a function. Multiple returns are a violation. -->

## Rule LGEDV_CRCL_0014:
Definition: Pointer parameters need to be null checked before using it, and out-of-bound index memory accessing (access array/vector by index) should be checked before using it.
When suggesting solution, solution should avoid violating of rule Misra 6-6-5: A function shall have a single point of exit at the end of the function. 

<!-- 
## Rule MISRA 6-5-1
**Definition**: A for loop shall contain a single loop-counter which shall not have floating type.

## Rule MISRA 6-5-5
**Definition**: A loop-control-variable other than the loop-counter shall not be modified within condition or expression

## Rule MISRA 6-6-2
**Definition**: The goto statement shall jump to a label declared later in the same function body.

## Rule MISRA 6-6-4
**Definition**: For any iteration statement there shall be no more than one break or goto statement used for loop termination.
**Exception**: None -->
